@@ -743,6 +743,9 @@ var settingsDialog = {
         value = value.replace(/[\s]/g, '');
         element.value = value;
         break;
+      case 6:
+        document.getElementById("deprecated_attachment").style.display = document.getElementById('text-attachments').value ? "" : "none"
+        break;
     }
 
     if (this.mPickedIndex[1] > -1) {
@@ -1340,6 +1343,13 @@ var settingsDialog = {
     this.enableSave();
   },
   // TODO: Hardcoding files is no longer possible in pure WebExt, either Exp only or gallery.
+  insertAttachmentVariable: async function () {
+    if ((file = await gQuicktext.pickFile([2], 0, extension.localeData.localizeMessage("attachmentFile"))) != null) {
+      this.insertVariable('ATTACHMENT=FILE|' + file.path);
+    }
+    this.enableSave();
+  },
+  // TODO: Hardcoding files is no longer possible in pure WebExt, either Exp only or gallery.
   insertFileVariable: async function () {
     if ((file = await gQuicktext.pickFile([2], 0, extension.localeData.localizeMessage("insertFile"))) != null) {
       this.insertVariable('FILE=' + file.path);
@@ -1349,7 +1359,7 @@ var settingsDialog = {
   // TODO: Hardcoding files is no longer possible in pure WebExt, either Exp only or gallery.
   insertImageVariable: async function () {
     if ((file = await gQuicktext.pickFile([4], 0, extension.localeData.localizeMessage("insertImage"))) != null) {
-      this.insertVariable('IMAGE=' + file.path);
+      this.insertVariable('IMAGE=FILE|' + file.path);
     }
     this.enableSave();
   },
@@ -1494,6 +1504,7 @@ var settingsDialog = {
       document.getElementById('text-keyword').value = text.keyword;
       document.getElementById('text-subject').value = text.subject;
       document.getElementById('text-attachments').value = text.attachments;
+      document.getElementById("deprecated_attachment").style.display = text.attachments ? "" : "none"
 
       document.getElementById('label-shortcutModifier').value = extension.localeData.localizeMessage(document.getElementById('select-shortcutModifier').value + "Key") + "+";
 
@@ -1530,6 +1541,7 @@ var settingsDialog = {
       document.getElementById("text-keyword").value = "";
       document.getElementById("text-subject").value = "";
       document.getElementById("text-attachments").value = "";
+      document.getElementById("deprecated_attachment").style.display = "none";
     }
 
     var disabled = false;
